measuretools.AnonymousMeasure
=============================

.. inheritance-diagram:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure
   :private-bases:

.. autoclass:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.contents_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.duration_in_seconds

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.is_binary

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.is_full

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.is_misfilled

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.is_nonbinary

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.is_overfull

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.is_underfull

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.leaves

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.lilypond_format

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.measure_number

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.multiplier

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.music

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.override

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.parent

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.preprolated_duration

    Inherited from :py:class:`measuretools.DynamicMeasure <abjad.tools.measuretools.DynamicMeasure.DynamicMeasure.DynamicMeasure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.prolated_duration

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.prolation

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.set

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.spanners

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.start_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.start_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.stop_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.stop_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.target_duration

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.always_format_time_signature

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.automatically_adjust_time_signature

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.denominator

    Inherited from :py:class:`measuretools.DynamicMeasure <abjad.tools.measuretools.DynamicMeasure.DynamicMeasure.DynamicMeasure>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.is_parallel

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.suppress_meter

    Inherited from :py:class:`measuretools.DynamicMeasure <abjad.tools.measuretools.DynamicMeasure.DynamicMeasure.DynamicMeasure>`

Methods
-------

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.append

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.extend

    Inherited from :py:class:`measuretools.DynamicMeasure <abjad.tools.measuretools.DynamicMeasure.DynamicMeasure.DynamicMeasure>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.index

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.insert

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.pop

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.remove

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__add__

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__contains__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__delitem__

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__getitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__iadd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__imul__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__len__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__mul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__radd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__repr__

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__rmul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__setitem__

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`

.. automethod:: abjad.tools.measuretools.AnonymousMeasure.AnonymousMeasure.AnonymousMeasure.__str__

    Inherited from :py:class:`measuretools.Measure <abjad.tools.measuretools.Measure.Measure.Measure>`
